.. _files:

Files
=====

In the context of Charmcraft, a *file* refers to any file in a project that can be
initialised or packed.

.. toctree::
    :maxdepth: 1

    actions-yaml-file
    charmcraft-yaml-file
    config-yaml-file
    contributing-md-file
    dispatch-file
    icon-svg-file
    libname-py-file
    license-file
    lxd-profile-yaml-file
    manifest-yaml-file
    metadata-yaml-file
    pyproject-toml-file
    readme-md-file
    requirements-txt-file
    src-charm-py-file
    src-workload-py-file
    tests-unit-test-charm-py-file
    tests-integration-conftest-py-file
    tests-integration-test-charm-py-file
    tox-ini-file
    uv-lock-file
